MetaLockedDownTraits
====================

.. currentmodule:: wwt_data_formats

.. autoclass:: MetaLockedDownTraits
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MetaLockedDownTraits.__call__
      ~MetaLockedDownTraits.mro
      ~MetaLockedDownTraits.register
      ~MetaLockedDownTraits.setup_class

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: mro
   .. automethod:: register
   .. automethod:: setup_class
